#ifndef BIJI_RENMAE_NOTE_H
#define BIJI_RENMAE_NOTE_H

#include <gtk/gtk.h>

gchar * note_title_dialog (GtkWindow *win, gchar *instructions, const gchar *title);


#endif
